@@ -24,10 +24,10 @@
 #include "config.h"
 #endif
 
+#include <xorg-server.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
-#define NEED_EVENTS
 #include <X11/X.h>
 #include <X11/Xproto.h>
 #include "inputstr.h"
@@ -36,7 +36,6 @@
 #include "xf86Priv.h"
 #include "xf86Xinput.h"
 #include "xf86_OSproc.h"
-#include "xf86OSmouse.h"
 #include "mouse.h"
 #include "mousePriv.h"
 
@@ -75,6 +74,7 @@ static symtab_t pnpprod[] = {
     { "KYE0001",  PROT_MS },		/* Genius PnP Mouse */
     { "KYE0002",  PROT_MS },		/* MouseSystem (Genius?) SmartScroll */
     { "KYE0003",  PROT_IMSERIAL },	/* Genius NetMouse */
+    { "KYE0004",  PROT_IMSERIAL },	/* Genius NetScroll+ (serial) */
     { "LGI800C",  PROT_IMSERIAL },	/* Logitech MouseMan (4 button model) */
     { "LGI8033",  PROT_IMSERIAL },	/* Logitech Cordless MouseMan Wheel */
     { "LGI8050",  PROT_IMSERIAL },	/* Logitech MouseMan+ */
